@@ -1,7 +1,11 @@
-from fanstatic import Group, Library, Resource
-from js.jquery import jquery
-from js.jqueryui import jqueryui
-# there's likely some lighter import option in the jqueryui fanstatic package
+# -*- coding: utf-8 -*-
+
+from fanstatic import Group
+from fanstatic import Library
+from fanstatic import Resource
+from js.jqueryui import ui_autocomplete
+from js.jqueryui import ui_widget
+
 
 library = Library('tagit', 'resources')
 
@@ -9,7 +13,7 @@ js = Resource(library,
               'tag-it.js',
               minified="tag-it.min.js",
               bottom=True,
-              depends=[jquery, jqueryui, ])
+              depends=[ui_autocomplete, ui_widget, ])
 css = Resource(library,
                'jquery.tagit.css',
                minified='jquery.tagit.min.css',
